#!/bin/bash

echo -e "****************************************************"
echo -e "* Setup Ras p-On control script                    *"
echo -e "*                          NEKORISU Co.,LTD.       *"
echo -e "****************************************************"

##############################################################
# Check configuration
#   check locale
#   check root permission
#   check existence of ntpdate
#      -> if not, install ntpdate
##############################################################

echo -e "Check configuration."

echo $LANG | grep -i -q "ja"
MESSAGE_LANG=$?

NETWORK_INSTALL=1
if [ $# -eq 1 ]; then
	if [ $1 = "-local" ]; then
		NETWORK_INSTALL=0
	fi
fi

if [ ${EUID:-${UID}} != 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[33mこのインストールスクリプトは、root権限が必要です。 sudo ./install.sh \e[m"
		echo -e "\e[33mインストールを中止しました。 \e[m"
	else
		echo -e "\e[33mThis installer must be run as root. Try 'sudo ./install.sh'\e[m"
		echo -e "\e[33mInstallation aborted.\e[m"
	fi
	exit 1
fi

if [ ${NETWORK_INSTALL} -eq 1 ]; then
	dpkg -l | grep -i -q "ntpdate"
	if [ $? -ne 0 ]; then
		if [ ${MESSAGE_LANG} -eq 0 ]; then
			echo -e "ntpdateをインストールします。"
		else
			echo -e "Install ntpdate."
		fi

		apt-get install -y ntpdate
		if [ $? -ne 0 ]; then
			if [ ${MESSAGE_LANG} -eq 0 ]; then
				echo -e "\e[31mError: ntpdateのインストールに失敗しました。 インターネットが使える環境か確認してください。\e[m"
				echo -e "\e[31mインストールを中止しました。\e[m"
			else
				echo -e "\e[31mError: Failed to install ntpdate. Check the Internet connection. \e[m"
				echo -e "\e[31mInstallation aborted.\e[m"
			fi
			exit 1
		fi
	fi
fi
echo -e "------> Done."


##############################################################
# Setup Switch control script
##############################################################
echo -e "Copy the script file. (pwrctl.sh -> /usr/local/bin/raspon)"
if [ ! -d /usr/local/bin/raspon ]; then
	mkdir -p -v /usr/local/bin/raspon
	if [ $? -ne 0 ]; then
		if [ ${MESSAGE_LANG} -eq 0 ]; then
			echo -e "\e[31mError: インストール先のディレクトリの作成に失敗しました。 /usr/local/bin/raspon\e[m"
			echo -e "\e[31mインストールを中止しました。\e[m"
		else
			echo -e "\e[31mError: Failed to create the target directory /usr/local/bin/raspon\e[m"
			echo -e "\e[31mInstallation aborted.\e[m"
		fi
		exit 1
	fi
fi

cp pwrctl.sh /usr/local/bin/raspon
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: ファイルのコピーに失敗しました。 (pwrctl.sh)\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to copy the script file. (pwrctl.sh)\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi

chmod a+x /usr/local/bin/raspon/pwrctl.sh
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: パーミッションの変更に失敗しました。\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to change permission.\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

echo -e "Copy the service definition file. (pwrctl.service -> /etc/systemd/system)"
cp pwrctl.service /etc/systemd/system
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: ファイルのコピーに失敗しました。\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to copy the service file.\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

echo -e "Regist the service."
systemctl daemon-reload
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: コマンドが実行できません。 'systemctl daemon-reload'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to do 'systemctl daemon-reload'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
systemctl enable pwrctl.service
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31nError: コマンドが実行できません。 'systemctl enable pwrctl.service'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31nError: Failed to do 'systemctl enable pwrctl.service'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
systemctl start pwrctl.service
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: コマンドが実行できません。 'systemctl start pwrctl.service'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to do 'systemctl start pwrctl.service'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

##############################################################
# Retup RTC control script
##############################################################
echo -e "Copy the script file. (rtcsetup.sh -> /usr/local/bin/raspon)"
if [ ! -d /usr/local/bin/raspon ]; then
	mkdir -p -v /usr/local/bin/raspon
	if [ $? -ne 0 ]; then
		if [ ${MESSAGE_LANG} -eq 0 ]; then
			echo -e "\e[31mError: インストール先のディレクトリの作成に失敗しました。 /usr/local/bin/raspon\e[m"
			echo -e "\e[31mインストールを中止しました。\e[m"
		else
			echo -e "\e[31mError: Failed to create the target directory /usr/local/bin/raspon\e[m"
			echo -e "\e[31mInstallation aborted.\e[m"
		fi
		exit 1
	fi
fi
cp rtcsetup.sh /usr/local/bin/raspon
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: ファイルのコピーに失敗しました。 (rtcsetup.sh)\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to copy the script file. (rtcsetup.sh)\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
chmod a+x /usr/local/bin/raspon/rtcsetup.sh
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: パーミッションの変更に失敗しました。\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to change permission.\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
if [ ${NETWORK_INSTALL} -eq 0 ]; then
	sed -i 's/RTC_LOCAL=0/RTC_LOCAL=1/g' /usr/local/bin/raspon/rtcsetup.sh
fi
echo -e "------> Done."

echo -e "Copy the service definition file. (rtcsetup.service -> /etc/systemd/system)"
cp rtcsetup.service /etc/systemd/system
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: ファイルのコピーに失敗しました。\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to copy the service file.\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

echo -e "Regist the service."
systemctl daemon-reload
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: コマンドが実行できません。 'systemctl daemon-reload'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to do 'systemctl daemon-reload'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
systemctl enable rtcsetup.service
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31nError: コマンドが実行できません。 'systemctl enable rtcsetup.service'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31nError: Failed to do 'systemctl enable rtcsetup.service'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
systemctl start rtcsetup.service
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: コマンドが実行できません。 'systemctl start rtcsetup.service'\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to do 'systemctl start rtcsetup.service'\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

##############################################################
# Enable DS1307 
##############################################################
echo -e "Enable I2C."
raspi-config nonint do_i2c 0
if [ $? -ne 0 ]; then
	if [ ${MESSAGE_LANG} -eq 0 ]; then
		echo -e "\e[31mError: I2CをONにできません。\e[m"
		echo -e "\e[31mインストールを中止します。\e[m"
	else
		echo -e "\e[31mError: Failed to enable I2C.\e[m"
		echo -e "\e[31mInstallation aborted.\e[m"
	fi
	exit 1
fi
echo -e "------> Done."

echo -e "Add i2c-dev to /etc/modules"
cat /etc/modules | grep -i -q "i2c-dev"
if [ $? -ne 0 ]; then
	echo "i2c-dev" >> /etc/modules
fi
echo -e "------> Done."

echo -e "Add rtc-ds1307 to /etc/modules"
cat /etc/modules | grep -i -q "rtc-ds1307"
if [ $? -ne 0 ]; then
	echo "rtc-ds1307" >> /etc/modules
fi
echo -e "------> Done."

echo -e "Disable default NTP service"
systemctl -l | grep -i -q "ntp"
if [ $? -eq 0 ]; then
	systemctl stop ntp.service
	systemctl disable ntp.service
fi
systemctl -l | grep -i -q "systemd-timesyncd.service"
if [ $? -eq 0 ]; then
	systemctl stop systemd-timesyncd.service
	systemctl disable systemd-timesyncd.service
fi
systemctl -l | grep -i -q "fake-hwclock.service"
if [ $? -eq 0 ]; then
	systemctl stop fake-hwclock.service
	systemctl disable fake-hwclock.service
fi
echo -e "------> Done."

echo -e "Edit /etc/default/hwclock"
cat /etc/default/hwclock | grep -i -q "HCTOSYS_DEVICE=rtc0"
if [ $? -eq 0 ]; then
	sed -i 's/#HCTOSYS_DEVICE=rtc0/HCTOSYS_DEVICE=rtc0/g' /etc/default/hwclock
else
	echo "HCTOSYS_DEVICE=rtc0" >> /etc/default/hwclock
fi
echo -e "------> Done."


if [ ${MESSAGE_LANG} -eq 0 ]; then
	echo -e "\e[32mインストールが正常に終了しました。\e[m"
	echo -e "\e[32m設定を反映するには、再起動が必要です。\e[m"
else
	echo -e "\e[32mInstallation succeeded.\e[m"
	echo -e "\e[32mYou need reboot the system in order to have changed activate. \e[m"
fi

exit 0





